@@ -42,6 +42,9 @@ enum {
 	SCREENSAVER_KEY,
 	FINANCE_KEY,
 	HELP_KEY,
+	WWW_KEY,
+	CALCULATOR_KEY,
+	RECORD_KEY,
 #ifdef USE_FBLEVEL
 	BRIGHT_DOWN_KEY,
 	BRIGHT_UP_KEY,
@@ -51,7 +54,7 @@ enum {
 
 
 static struct {
-	char key_type;
+	int key_type;
 	const char *key_config;
 	const char *description;
 	int key_code;
@@ -80,6 +83,12 @@ static struct {
 		N_("Finance key"), -1},
 	{ HELP_KEY, "/apps/acme/help_key",
 		N_("Help key"), -1},
+	{ WWW_KEY, "/apps/acme/www_key",
+		N_("WWW key"), -1},
+	{ CALCULATOR_KEY, "/apps/acme/calculator_key",
+		N_("Calculator key"), -1 },
+	{ RECORD_KEY, "/apps/acme/record_key",
+		N_("Record key"), -1 },
 #ifdef USE_FBLEVEL
 	{ BRIGHT_DOWN_KEY, "/apps/acme/brightness_down",
 		N_("Brightness down key"), 101},
